==> projectx-sdk-1.0.66-1-20210421.084521-6-sources.jar: cn/com/duiba/projectx/sdk/component/sendprize/SendPrizeApi.java <==
package cn.com.duiba.projectx.sdk.component.sendprize;

import cn.com.duiba.projectx.sdk.UserRequestApi;
import cn.com.duiba.projectx.sdk.component.sendprize.dto.SendPrizeResult;
import cn.com.duiba.projectx.sdk.data.Option;
import cn.com.duiba.projectx.sdk.playway.base.Prize;
import cn.com.duiba.projectx.sdk.playway.base.PrizeStock;

import java.util.List;
import java.util.Map;

/**
 * @program: projectx
 * @description: 组件化 - 发奖组件
 * @author: Simba
 * @create: 2021-02-19 16:27
 **/
public interface SendPrizeApi extends UserRequestApi {

    /**
     * 使用发奖策略出奖
     *
     * @param strategyId 发奖策略ID
     * @return 奖项
     */
    SendPrizeResult sendPrize(String strategyId);

    /**
     * 使用发奖策略出奖
     * 可以指定一个用户进行策略发奖
     *
     * @param userId     userId
     * @param strategyId 发奖策略ID
     * @return 奖项
     */
    SendPrizeResult sendPrizeWithUserId(String userId, String strategyId);

    /**
     * 给用户发放道具
     *
     * @param userId   userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(String userId, String spId, int quantity);

    /**
     * 获取某个发奖策略下面的奖项列表
     *
     * @param strategyId 发奖策略id
     * @return list
     */
    List<Option> queryOptions(String strategyId);

    /**
     * 查询指定奖品信息
     *
     * @param prizeId
     * @return
     */
    Prize getPrize(String prizeId);

    /**
     * 根据奖品id查询奖品信息
     *
     * @param prizeIds
     * @return
     */
    List<Prize> getPrizeList(List<String> prizeIds);

    /**
     * 根据奖品id查询库存
     *
     * @param prizeId
     * @return
     */
    PrizeStock getPrizeStock(String prizeId);

    /**
     * 批量获取奖品库存信息
     *
     * @param ids prize ids
     * @return prize stock list
     */
    List<PrizeStock> listPrizeStock(List<String> ids);

    /**
     * 查询某人的某个道具的数量
     *
     * @param userId 需要查询的用户
     * @param spId   道具id
     * @return
     */
    Long getSomebodyStageProperty(String userId, String spId);

    /**
     * 查询某人部分道具的数量
     *
     * @param userId 需要查询的用户
     * @param spIds  道具id集合
     * @return
     */
    Map<String, Long> getSomebodySomeStageProperty(String userId, List<String> spIds);

    /**
     * 消耗某个用户的道具
     *
     * @param userId   userId
     * @param spId     spId
     * @param quantity 数量
     * @return 消耗是否成功
     */
    Boolean consumeStageProperty(String userId, String spId, int quantity);


}

==> projectx-sdk-1.1.41-sources.jar: cn/com/duiba/projectx/sdk/component/sendprize/SendPrizeApi.java <==
package cn.com.duiba.projectx.sdk.component.sendprize;

import cn.com.duiba.projectx.sdk.UserRequestApi;
import cn.com.duiba.projectx.sdk.component.sendprize.dto.SendPrizeResult;
import cn.com.duiba.projectx.sdk.component.sendprize.dto.UserPrizeRecordResult;
import cn.com.duiba.projectx.sdk.data.Option;
import cn.com.duiba.projectx.sdk.playway.base.Prize;
import cn.com.duiba.projectx.sdk.playway.base.PrizeStock;

import java.util.List;
import java.util.Map;

/**
 * @program: projectx
 * @description: 组件化 - 发奖组件
 * @author: Simba
 * @create: 2021-02-19 16:27
 **/
public interface SendPrizeApi extends UserRequestApi {

    /**
     * 使用发奖策略出奖
     *
     * @param strategyId 发奖策略ID
     * @return 奖项
     */
    SendPrizeResult sendPrize(String strategyId);

    /**
     * 使用发奖策略出奖
     * 可以指定一个用户进行策略发奖
     *
     * @param userId     userId
     * @param strategyId 发奖策略ID
     * @return 奖项
     */
    SendPrizeResult sendPrizeWithUserId(String userId, String strategyId);

    /**
     * 给用户发放道具
     *
     * @param userId   userId
     * @param spId     道具ID
     * @param quantity 道具个数
     * @return 记录ID
     */
    Long giveStageProperty(String userId, String spId, int quantity);

    /**
     * 获取某个发奖策略下面的奖项列表
     *
     * @param strategyId 发奖策略id
     * @return list
     */
    List<Option> queryOptions(String strategyId);

    /**
     * 查询指定奖品信息
     *
     * @param prizeId
     * @return
     */
    Prize getPrize(String prizeId);

    /**
     * 根据奖品id查询奖品信息
     *
     * @param prizeIds
     * @return
     */
    List<Prize> getPrizeList(List<String> prizeIds);

    /**
     * 根据奖品id查询库存
     *
     * @param prizeId
     * @return
     */
    PrizeStock getPrizeStock(String prizeId);

    /**
     * 批量获取奖品库存信息
     *
     * @param ids prize ids
     * @return prize stock list
     */
    List<PrizeStock> listPrizeStock(List<String> ids);

    /**
     * 查询某人的某个道具的数量
     *
     * @param userId 需要查询的用户
     * @param spId   道具id
     * @return
     */
    Long getSomebodyStageProperty(String userId, String spId);

    /**
     * 查询某人部分道具的数量
     *
     * @param userId 需要查询的用户
     * @param spIds  道具id集合
     * @return
     */
    Map<String, Long> getSomebodySomeStageProperty(String userId, List<String> spIds);

    /**
     * 消耗某个用户的道具
     *
     * @param userId   userId
     * @param spId     spId
     * @param quantity 数量
     * @return 消耗是否成功
     */
    Boolean consumeStageProperty(String userId, String spId, int quantity);



    Boolean consumeStageProperty(String userId, String spId, long quantity);

    /**
     * 查询中奖信息
     * @param userId
     * @param recordId
     * @return
     */
    UserPrizeRecordResult getUserPrizeRecord(String userId, Long recordId);

}
